@@ -961,8 +961,9 @@ sub get {
 			},
 			file => {
 				files => 'Files',
-				'open' => 'Open File',
+				open => 'Open File',
 				insert => 'Insert File',
+				rename => 'Rename File',
 				save_as => 'Save File As',
 				save_all => 'Save All',
 				save_none => 'Save None',
@@ -977,6 +978,11 @@ sub get {
 				save_session => 'Save Current File Session',
 				import_session => 'Import File Session',
 				export_session => 'Export File Session',
+				open_dir => 'Open Files of Directory :',
+				file_changed => 'File Changed',
+				file_changed_msg => 'The following file has changed :',
+				file_deleted => 'File Deleted',
+				file_deleted_msg = 'The following file can not be found anymore :',
 			},
 			general => {
 				apply => 'Apply',
@@ -984,9 +990,9 @@ sub get {
 				overwrite => 'Overwrite',
 				restore => 'Restore',
 				cancel => 'Cancel',
-				'close' => 'Close',
+				close => 'Close',
 				all => 'All',
-				'select' => 'Select',
+				select => 'Select',
 				selected => 'Selected',
 				none => 'None',
 				dont_allow => 'Your settings dont allow this.',
@@ -1000,7 +1006,7 @@ sub get {
 				more => 'explicit licenses',
 				homepage => 'for more info visit',
 				contains => 'this version contains',
-				'and' => 'and',
+				and => 'and',
 				wrappes => 'which wrappes',
 				extra => 'extra Perl Modules',
 				dedication => 'Deditcated to all people who ever tried to write an editor.',
